<?php

namespace Drupal\typography_filter\Plugin\Filter;

use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;
use JoliTypo\Fixer;

/**
 * @Filter(
 *   id = "filter_typography",
 *   title = @Translation("Improve typography"),
 *   description = @Translation("Use <a href=""https://github.com/jolicode/JoliTypo"">JoliTypo</a> to automatically fix typography by dealing with spaces around punctuation marks, replacing quotes, hyphenating, etc."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_TRANSFORM_IRREVERSIBLE,
 * )
 */
class FilterTypography extends FilterBase {

  /**
   * @inheritDoc
   */
  public function process($text, $langcode) {
    $fixer = $this->initFixer($langcode);
    if ($fixer instanceof Fixer) {
      $text = $fixer->fix($text);
    }
    return new FilterProcessResult($text);
  }

  /**
   * Get the fixer according to the given langcode.
   *
   * Returns the fixer configured for the given langocde or NULL if the langcode
   * is not supported yet.
   *
   * @param string $langcode
   *   The language code of the text to be filtered.
   *
   * @return JoliTypoe\Fixer|NULL
   *   The configured fixer.
   *
   * @see https://github.com/jolicode/JoliTypo#fixer-recommendations-by-locale
   * @TODO make it configurable.
   */
  protected function initFixer($langcode) {
    switch ($langcode) {
      case 'en':
        $fixers = ['Ellipsis', 'Dimension', 'Unit', 'Dash', 'SmartQuotes', 'NoSpaceBeforeComma', 'CurlyQuote', 'Hyphen', 'Trademark'];
        $locale = 'en_GB';
        break;

      case 'fr':
        $fixers = ['Ellipsis', 'Dimension', 'Unit', 'Dash', 'SmartQuotes', 'FrenchNoBreakSpace', 'NoSpaceBeforeComma', 'CurlyQuote', 'Hyphen', 'Trademark'];
        $locale = 'fr_FR';
        break;

      case 'de':
        $fixers = ['Ellipsis', 'Dimension', 'Unit', 'Dash', 'SmartQuotes', 'NoSpaceBeforeComma', 'CurlyQuote', 'Hyphen', 'Trademark'];
        $locale = 'de_DE';
        break;

      default:
        return NULL;
    }

    $fixer = new Fixer($fixers);
    $fixer->setLocale($locale);
    return $fixer;
  }

}
